@@ -79,10 +79,6 @@
 
 #define VTE_TERMINFO_NAME "xterm-256color"
 
-#if !GLIB_CHECK_VERSION(2, 42, 0)
-#define G_PARAM_EXPLICIT_NOTIFY 0
-#endif
-
 #define I_(string) (g_intern_static_string(string))
 
 typedef struct _VtePtyPrivate VtePtyPrivate;
